@@ -7,5 +7,5 @@ def clear_console(type="full"):
         else:
             system("clear")
     elif type == "line":
-        print(100*" ",end="\r")
+        print(100*" ",end="\r\r")
     
\ No newline at end of file
