@@ -6,4 +6,4 @@ def animate_print(text,delay=0.05):
         custom_text.append(i)
         time.sleep(delay)
         print("".join(custom_text),end="\r")
-    print("\n")
\ No newline at end of file
+    print("\n\n")
\ No newline at end of file
